@@ -1,10 +1,10 @@
 /*
- * Logswan 2.1.8
- * Copyright (c) 2015-2020, Frederic Cambus
+ * Logswan 2.1.10
+ * Copyright (c) 2015-2021, Frederic Cambus
  * https://www.logswan.org
  *
  * Created:      2015-05-31
- * Last Updated: 2020-07-02
+ * Last Updated: 2021-02-15
  *
  * Logswan is released under the BSD 2-Clause license.
  * See LICENSE file for details.
@@ -13,7 +13,7 @@
 #ifndef CONFIG_H
 #define CONFIG_H
 
-#define VERSION "Logswan 2.1.8"
+#define VERSION "Logswan 2.1.10"
 
 enum {
 	HLL_BITS = 20,
@@ -26,7 +26,7 @@ enum {
 	PROTOCOLS = 4
 };
 
-extern char *methodsNames[];
-extern char *protocolsNames[];
+extern char *methods_names[];
+extern char *protocols_names[];
 
 #endif /* CONFIG_H */
