@@ -1,10 +1,10 @@
 /*
- * Logswan 2.1.8
- * Copyright (c) 2015-2020, Frederic Cambus
+ * Logswan 2.1.10
+ * Copyright (c) 2015-2021, Frederic Cambus
  * https://www.logswan.org
  *
  * Created:      2015-05-31
- * Last Updated: 2019-01-19
+ * Last Updated: 2021-02-15
  *
  * Logswan is released under the BSD 2-Clause license.
  * See LICENSE file for details.
@@ -13,8 +13,8 @@
 #ifndef COUNTRIES_H
 #define COUNTRIES_H
 
-extern char *countriesId[];
-extern char *countriesNames[];
+extern char *countries_id[];
+extern char *countries_names[];
 
 #endif /* COUNTRIES */
 
