@@ -1,10 +1,10 @@
 /*
- * Logswan 2.1.8
- * Copyright (c) 2015-2020, Frederic Cambus
+ * Logswan 2.1.10
+ * Copyright (c) 2015-2021, Frederic Cambus
  * https://www.logswan.org
  *
  * Created:      2015-05-31
- * Last Updated: 2019-01-19
+ * Last Updated: 2021-02-15
  *
  * Logswan is released under the BSD 2-Clause license.
  * See LICENSE file for details.
@@ -22,12 +22,12 @@ struct date {
 	char *second;
 };
 
-struct logLine {
-	char *remoteHost;
+struct logline {
+	char *remote_host;
 	char *date;
 	char *request;
-	char *statusCode;
-	char *objectSize;
+	char *status_code;
+	char *object_size;
 };
 
 struct request {
@@ -36,8 +36,8 @@ struct request {
 	char *protocol;
 };
 
-void parseDate(struct date *, char *);
-void parseLine(struct logLine *, char *);
-void parseRequest(struct request *, char *);
+void parse_date(struct date *, char *);
+void parse_line(struct logline *, char *);
+void parse_request(struct request *, char *);
 
 #endif /* PARSE_H */
